@@ -30,14 +30,14 @@ class TestSecurityReportsBandit(ReportProcessingTestCase):
     def test_get_security_indicator_bandit_report(self) -> None:
         """Test retrieving report from local path."""
         si_bandit_reports = SecurityIndicatorsBandit.aggregate_security_indicator_bandit_results(
-            security_indicator_bandit_repo_path=self._SI_BANDIT_FOLDER_PATH
+            security_indicator_bandit_repo_path=self._SI_BANDIT_FOLDER_PATH, is_local=True
         )
         assert si_bandit_reports[0]
 
     def test_get_metadata_df_from_bandit_report(self) -> None:
         """Test obtaining metadata from si bandit report."""
         si_bandit_reports = SecurityIndicatorsBandit.aggregate_security_indicator_bandit_results(
-            security_indicator_bandit_repo_path=self._SI_BANDIT_FOLDER_PATH
+            security_indicator_bandit_repo_path=self._SI_BANDIT_FOLDER_PATH, is_local=True
         )
         si_bandit_report = si_bandit_reports[0]
         si_bandit = SecurityIndicatorsBandit()
@@ -57,7 +57,7 @@ class TestSecurityReportsBandit(ReportProcessingTestCase):
     def test_get_severity_confidence_info_from_bandit_report(self) -> None:
         """Test obtaining severity confidence info from si bandit report."""
         si_bandit_reports = SecurityIndicatorsBandit.aggregate_security_indicator_bandit_results(
-            security_indicator_bandit_repo_path=self._SI_BANDIT_FOLDER_PATH
+            security_indicator_bandit_repo_path=self._SI_BANDIT_FOLDER_PATH, is_local=True
         )
         si_bandit_report = si_bandit_reports[0]
         si_bandit = SecurityIndicatorsBandit()
@@ -80,7 +80,7 @@ class TestSecurityReportsBandit(ReportProcessingTestCase):
     def test_get_severity_confidence_info_df_from_bandit_report(self) -> None:
         """Test obtaining severity confidence info DataFrame from si bandit report."""
         si_bandit_reports = SecurityIndicatorsBandit.aggregate_security_indicator_bandit_results(
-            security_indicator_bandit_repo_path=self._SI_BANDIT_FOLDER_PATH
+            security_indicator_bandit_repo_path=self._SI_BANDIT_FOLDER_PATH, is_local=True
         )
         si_bandit_report = si_bandit_reports[0]
         si_bandit = SecurityIndicatorsBandit()
