@@ -55,7 +55,7 @@ class _SecurityIndicators:
         store_files: Optional[List[str]] = None,
         limit_results: bool = False,
         max_ids: int = 5,
-        is_local: bool = True,
+        is_local: bool = False,
         repo_path: Optional[Path] = None,
     ) -> Dict[str, Any]:
         """Aggregate results stored on Ceph or locally from repo for Thoth components reports.
@@ -475,6 +475,8 @@ class SecurityIndicatorsBandit(_SecurityIndicators):
 
             counter += 1
 
+        final_df.reset_index(inplace=True, drop=True)
+
         return final_df
 
     def create_security_indicators_scores(self, si_bandit_df: pd.DataFrame) -> pd.DataFrame:
@@ -667,6 +669,8 @@ class SecurityIndicatorsCloc:
 
             counter += 1
 
+        final_df.reset_index(inplace=True, drop=True)
+
         return final_df
 
 
@@ -743,6 +747,8 @@ class SecurityIndicatorsAggregator:
 
         aggregated_df = pd.concat([package_df, si_bandit_df, si_cloc_df], axis=1)
 
+        aggregated_df.reset_index(inplace=True, drop=True)
+
         return aggregated_df
 
     def create_si_aggregated_json(
